==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_d3_d9_hardware_pixel_buffer.js <==
var class_ogre_1_1_d3_d9_hardware_pixel_buffer =
[
    [ "D3D9HardwarePixelBuffer", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#adaccb76df4d0e3483c916723f89f9775", null ],
    [ "~D3D9HardwarePixelBuffer", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a4aaa5a26ed3fd91c5fd1e330a5d7e751", null ],
    [ "bind", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a3ebff4ac2054c8ca8890d612914f07da", null ],
    [ "bind", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a20fdd929d780f7f5ab3833aa4f6cad83", null ],
    [ "blit", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#af22166df8f8941b59003eb8702d7a5eb", null ],
    [ "blitFromMemory", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#abb6f9c69b9cf47425a48de93d2f2c1f7", null ],
    [ "blitToMemory", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a41213783503edf53ae62eb1cf0003aef", null ],
    [ "_genMipmaps", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#aa3ea1fd7592237c28a13bad09099529b", null ],
    [ "_setMipmapping", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a728dd8911efa390565708acbbce050d5", null ],
    [ "getRenderTarget", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#ae1f2dc631a0cb31f9125bb657800aa5e", null ],
    [ "getSurface", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a8d16bed21dcd7698886c90db4357ecba", null ],
    [ "getFSAASurface", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a968edc2ffcbf45286dd64ca841294c13", null ],
    [ "releaseSurfaces", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#ab5153b6892ecc27c4b7e7aa81fbb674e", null ],
    [ "destroyBufferResources", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a03af114b7c8c5523959b81e8201ea08d", null ],
    [ "lockDeviceAccess", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#aaa3b402158015eb4e91c53c5c0c0326c", null ],
    [ "unlockDeviceAccess", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#ac9e1e4727246461675003a184ae03ccb", null ]
];

==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_d3_d9_hardware_pixel_buffer.js <==
var class_ogre_1_1_d3_d9_hardware_pixel_buffer =
[
    [ "D3D9HardwarePixelBuffer", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#adaccb76df4d0e3483c916723f89f9775", null ],
    [ "~D3D9HardwarePixelBuffer", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a4aaa5a26ed3fd91c5fd1e330a5d7e751", null ],
    [ "bind", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a3ebff4ac2054c8ca8890d612914f07da", null ],
    [ "bind", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a20fdd929d780f7f5ab3833aa4f6cad83", null ],
    [ "blit", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#af22166df8f8941b59003eb8702d7a5eb", null ],
    [ "blitFromMemory", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#abb6f9c69b9cf47425a48de93d2f2c1f7", null ],
    [ "blitToMemory", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a41213783503edf53ae62eb1cf0003aef", null ],
    [ "_genMipmaps", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#aa3ea1fd7592237c28a13bad09099529b", null ],
    [ "_setMipmapping", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a728dd8911efa390565708acbbce050d5", null ],
    [ "getRenderTarget", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#ae1f2dc631a0cb31f9125bb657800aa5e", null ],
    [ "getSurface", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a8d16bed21dcd7698886c90db4357ecba", null ],
    [ "getFSAASurface", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a968edc2ffcbf45286dd64ca841294c13", null ],
    [ "getNullSurface", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a33a9bedc1dd795f65e65d77413b210e8", null ],
    [ "releaseSurfaces", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#ab5153b6892ecc27c4b7e7aa81fbb674e", null ],
    [ "destroyBufferResources", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#a03af114b7c8c5523959b81e8201ea08d", null ],
    [ "lockDeviceAccess", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#aaa3b402158015eb4e91c53c5c0c0326c", null ],
    [ "unlockDeviceAccess", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html#ac9e1e4727246461675003a184ae03ccb", null ]
];
